.. _dev:

#############
 Development
#############

Here are some guidelines for those who which to contribute to icclim
development.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   release_process
   ci
   contributing
